==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El dispositiu està ocupat</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Envia l’últim vídeo per correu</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Envia un o més vídeos seleccionats</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envia</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Podeu trobar el vídeo com un fitxer adjunt</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Seleccioneu un o més fitxers</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Vora</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El dispositiu està ocupat</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Àrea</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliació</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Àudio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Per defecte</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Còdec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No enregistris el cursor del ratolí</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Camí del vídeo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimitza el Vokoscreen en iniciar l’enregistrament</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reprodueix</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envia</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Temps d’enregistrament</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Mida en kB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Obre la carpeta</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Compte regressiu</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Reprodueix l’últim vídeo</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Envia el vídeo</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccioneu un o més dispositius</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Go</source>
        <translation>Vés-hi</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Lloc web</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Assistència</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Desenvolupador</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogramas</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Feu una donació</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Programa per a l’enregistrament</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduccions</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Càmera web</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Seleccioneu la càmera web</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.5.0.orig.tar.gz: vokoscreen-2.5.0/language/vokoscreen_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El dispositiu està ocupat</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Show Click Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Envia l’últim vídeo per correu</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Envia un o més vídeos seleccionats</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envia</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Podeu trobar el vídeo com un fitxer adjunt</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Seleccioneu un o més fitxers</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Vora</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>El dispositiu està ocupat</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Àrea</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ampliació</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Àudio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Per defecte</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Còdec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>No enregistris el cursor del ratolí</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Camí del vídeo</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Reproductor</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimitza el Vokoscreen en iniciar l’enregistrament</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inicia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reprodueix</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Envia</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Temps d’enregistrament</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Mida en kB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Obre la carpeta</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Compte regressiu</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Reprodueix l’últim vídeo</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Envia el vídeo</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleccioneu un o més dispositius</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Go</source>
        <translation>Vés-hi</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Lloc web</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Assistència</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Desenvolupador</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogramas</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Feu una donació</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduccions</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in systray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>New version available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Càmera web</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Seleccioneu la càmera web</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recorder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select recorder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lossless</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
